@@ -1,11 +1,11 @@
 package Treex::Block::W2A::CS::ParseMSTperl;
-$Treex::Block::W2A::CS::ParseMSTperl::VERSION = '0.13100';
+$Treex::Block::W2A::CS::ParseMSTperl::VERSION = '2.20151102';
 use strict;
 use warnings;
 use Moose;
 extends 'Treex::Block::W2A::ParseMSTperl';
 
-has 'model_name' => ( is => 'ro', isa => 'Str', default => 'pdt_form_small' ); #pdt_dz_wf_3 was here, but I cannot find such a model in share
+has 'model_name' => ( is => 'ro', isa => 'Str', default => 'pdt_form_small' ); #best: pdt_best
 has 'model_dir' => ( is => 'ro', isa => 'Str', default => "data/models/parser/mst_perl/cs" );
 
 has 'alignment_language' => ( isa => 'Str', is => 'ro', default => 'en' );
@@ -13,7 +13,7 @@ has 'alignment_is_backwards' => ( isa => 'Bool', is => 'ro', default => '1' );
 
 sub get_coarse_grained_tag {
     my ( $self, $tag ) = @_;
-    
+
     my $ctag;
     if ( substr( $tag, 4, 1 ) eq '-' ) {
 	# no case -> Pos + Subpos
@@ -29,14 +29,14 @@ sub get_coarse_grained_tag {
 1;
 
 __END__
- 
+
 =head1 NAME
 
 Treex::Block::W2A::CS::ParseMSTperl
 
 =head1 VERSION
 
-version 0.13100
+version 2.20151102
 
 =head1 DECRIPTION
 
